@@ -238,19 +238,19 @@ def plot1(freq,ZQS, labels, max_Z):
     pgf_with_latex["figure.figsize"] = figsize(1.4)[::-1]
     mpl.rcParams.update(pgf_with_latex)
     n = len(ZQS[0])-1
-    
-    if(max_Z > np.max(ZQS) or max_Z < 0.0):
-        max_Z = np.max(ZQS)
 
-    fig, axs = plt.subplots(n, sharex=True, sharey=True, gridspec_kw={'hspace': 0})
+    fig, axs = plt.subplots(n, sharex=True, gridspec_kw={'hspace': 0})
     if not (type(axs) == np.ndarray):
         axs = [axs]
     for i in range(n):
+        if(max_Z > np.max(ZQS[:,i+1]) or max_Z < 0.0):
+            max_Z_used = np.max(ZQS[:,i+1])*1.15
+            min_Z_used = -0.05*max_Z_used
         axs[i].plot(freq,ZQS[:,0], ':', color='grey')
         axs[i].text(.75,.75,labels[i],fontsize=12,horizontalalignment='center', verticalalignment='center',transform=axs[i].transAxes)
         axs[i].plot(freq, ZQS[:,i+1])
-    plt.ylim(top=max_Z)
-    plt.yticks([])
+        axs[i].set_ylim(bottom=min_Z_used, top=max_Z_used)
+        axs[i].set_yticks([])
 #    plt.ylabel('K-point DOS [kB T * ps]')
     plt.xlabel('Frequency [Thz]')
     plt.tight_layout()
@@ -268,18 +268,21 @@ def plot2(freq,ZQS,modes, labels, freqs_from_disp, max_Z):
         max_Z = np.max(ZQS)
 
     for n in range(n_kpoints): #iterating over the k points
-        fig, axs = plt.subplots(n_modes, sharex=True, sharey=True, gridspec_kw={'hspace': 0})
+        fig, axs = plt.subplots(n_modes, sharex=True,  gridspec_kw={'hspace': 0})
         if not (type(axs) == np.ndarray):
             axs = [axs]
         for i in range(n_modes): #iterating over the modes
             mode = modes[i]
+            if(max_Z > np.max(ZQS[n,:,mode+1]) or max_Z < 0.0):
+                max_Z_used = np.max(ZQS[n,:,mode+1])*1.15
+                min_Z_used = -0.05*max_Z_used
             axs[i].plot(np.repeat(freqs_from_disp[mode,n],100),np.linspace(0,ZQS[n,:,:].max(),100), c='r', label='freq from dispersion')
             axs[i].plot(freq,ZQS[n,:,0], ':', color='grey')
             axs[i].text(.75,.75,labels[n]+str('\n mode')+str(mode),fontsize=12,horizontalalignment='center', verticalalignment='center',transform=axs[i].transAxes)
             axs[i].plot(freq, ZQS[n,:,mode+1])
-
-        plt.yticks([])
-        plt.ylim(top=max_Z)
+            axs[i].set_ylim(bottom=min_Z_used, top=max_Z_used)
+            axs[i].set_yticks([])
+        
 #        plt.ylabel('K-point DOS [kB T * ps]')
         plt.xlabel('Frequency [Thz]')
         plt.tight_layout()
